DaemonRpc class

Constructors

DaemonRpc(Client client, String rpcUrl, {String? username, String? password})

Properties

baseUrl String
latefinal
client → Client
final
hashCode int
The hash code for this object.
no setterinherited
password String?
final
rpcUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String?
final

Methods

call(String method, Map<String, dynamic> params) Future<Map<String, dynamic>>
Perform a JSON-RPC call. If username and password are provided, use digest authentication. Otherwise, just do a single request without auth.
getOut(int index) Future<GetOutsResponse>
getOuts(List<int> keyOffsets) Future<GetOutsResponse>
Get a list of outputs by their absolute key offsets.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postToEndpoint(String endpoint, Map<String, dynamic> params) Future<Map<String, dynamic>>
Perform a direct HTTP POST request to an endpoint.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

rawRequestRpc(Uri rpcUri, String method, Map<String, dynamic> params, [String? authHeaderValue]) String
Raw request ready for a JSON-RPC call with authentication if the Authorization value is provided