DaemonRpc class
Properties
Methods
-
call(
String method, Map< String, dynamic> params) → Future<Map< String, dynamic> > - Perform a JSON-RPC call. If username and password are provided, use digest authentication. Otherwise, just do a single request without auth.
-
getOut(
int index) → Future< GetOutsResponse> -
getOuts(
List< int> keyOffsets) → Future<GetOutsResponse> - Get a list of outputs by their absolute key offsets.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postToEndpoint(
String endpoint, Map< String, dynamic> params) → Future<Map< String, dynamic> > - Perform a direct HTTP POST request to an endpoint.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited